@@ -18,10 +18,6 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so libGL.so )
 ( cd usr/lib ; rm -rf libGL.so.1 )
 ( cd usr/lib ; ln -sf /usr/X11R6/lib/libGL.so.1 libGL.so.1 )
-( cd usr/lib ; rm -rf libfreetype.so.6 )
-( cd usr/lib ; ln -sf libfreetype.so.6.3.15 libfreetype.so.6 )
-( cd usr/lib ; rm -rf libfreetype.so )
-( cd usr/lib ; ln -sf libfreetype.so.6.3.15 libfreetype.so )
 ( cd usr/X11R6/lib/X11 ; rm -rf app-defaults )
 ( cd usr/X11R6/lib/X11 ; ln -sf ../../../../etc/X11/app-defaults app-defaults )
 ( cd usr/X11R6/lib/X11 ; rm -rf proxymngr )
@@ -98,14 +94,22 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib/X11/icons/handhelds/cursors ; ln -sf left_ptr top_left_arrow )
 ( cd usr/X11R6/lib/X11/icons/handhelds/cursors ; rm -rf 08e8e1c95fe2fc01f976f1e063a24ccd )
 ( cd usr/X11R6/lib/X11/icons/handhelds/cursors ; ln -sf left_ptr_watch 08e8e1c95fe2fc01f976f1e063a24ccd )
+( cd usr/X11R6/lib ; rm -rf libXau.so.6 )
+( cd usr/X11R6/lib ; ln -sf libXau.so.6.0 libXau.so.6 )
+( cd usr/X11R6/lib ; rm -rf libXau.so )
+( cd usr/X11R6/lib ; ln -sf libXau.so.6.0 libXau.so )
+( cd usr/X11R6/lib ; rm -rf libXdmcp.so.6 )
+( cd usr/X11R6/lib ; ln -sf libXdmcp.so.6.0 libXdmcp.so.6 )
+( cd usr/X11R6/lib ; rm -rf libXdmcp.so )
+( cd usr/X11R6/lib ; ln -sf libXdmcp.so.6.0 libXdmcp.so )
 ( cd usr/X11R6/lib ; rm -rf libX11.so.6 )
 ( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so.6 )
 ( cd usr/X11R6/lib ; rm -rf libX11.so )
 ( cd usr/X11R6/lib ; ln -sf libX11.so.6.2 libX11.so )
 ( cd usr/X11R6/lib ; rm -rf libICE.so.6 )
-( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so.6 )
+( cd usr/X11R6/lib ; ln -sf libICE.so.6.4 libICE.so.6 )
 ( cd usr/X11R6/lib ; rm -rf libICE.so )
-( cd usr/X11R6/lib ; ln -sf libICE.so.6.3 libICE.so )
+( cd usr/X11R6/lib ; ln -sf libICE.so.6.4 libICE.so )
 ( cd usr/X11R6/lib ; rm -rf libSM.so.6 )
 ( cd usr/X11R6/lib ; ln -sf libSM.so.6.0 libSM.so.6 )
 ( cd usr/X11R6/lib ; rm -rf libSM.so )
@@ -202,18 +206,6 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libGLw.so.1.0 libGLw.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libGLw.so )
 ( cd usr/X11R6/lib ; ln -sf libGLw.so.1.0 libGLw.so )
-( cd usr/X11R6/lib ; rm -rf libdps.so.1 )
-( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so.1 )
-( cd usr/X11R6/lib ; rm -rf libdps.so )
-( cd usr/X11R6/lib ; ln -sf libdps.so.1.0 libdps.so )
-( cd usr/X11R6/lib ; rm -rf libdpstk.so.1 )
-( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so.1 )
-( cd usr/X11R6/lib ; rm -rf libdpstk.so )
-( cd usr/X11R6/lib ; ln -sf libdpstk.so.1.0 libdpstk.so )
-( cd usr/X11R6/lib ; rm -rf libpsres.so.1 )
-( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so.1 )
-( cd usr/X11R6/lib ; rm -rf libpsres.so )
-( cd usr/X11R6/lib ; ln -sf libpsres.so.1.0 libpsres.so )
 ( cd usr/X11R6/lib ; rm -rf libXinerama.so.1 )
 ( cd usr/X11R6/lib ; ln -sf libXinerama.so.1.0 libXinerama.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXinerama.so )
@@ -222,10 +214,6 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libXrender.so.1.2.2 libXrender.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXrender.so )
 ( cd usr/X11R6/lib ; ln -sf libXrender.so.1.2.2 libXrender.so )
-( cd usr/X11R6/lib ; rm -rf libfontconfig.so.1 )
-( cd usr/X11R6/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so.1 )
-( cd usr/X11R6/lib ; rm -rf libfontconfig.so )
-( cd usr/X11R6/lib ; ln -sf libfontconfig.so.1.2.0 libfontconfig.so )
 ( cd usr/X11R6/lib ; rm -rf libXft.so.1 )
 ( cd usr/X11R6/lib ; ln -sf libXft.so.1.1 libXft.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXft.so.2 )
@@ -240,6 +228,18 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libI810XvMC.so.1.0 libI810XvMC.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libI810XvMC.so )
 ( cd usr/X11R6/lib ; ln -sf libI810XvMC.so.1.0 libI810XvMC.so )
+( cd usr/X11R6/lib ; rm -rf libviaXvMC.so.1 )
+( cd usr/X11R6/lib ; ln -sf libviaXvMC.so.1.0 libviaXvMC.so.1 )
+( cd usr/X11R6/lib ; rm -rf libviaXvMC.so )
+( cd usr/X11R6/lib ; ln -sf libviaXvMC.so.1.0 libviaXvMC.so )
+( cd usr/X11R6/lib ; rm -rf libviaXvMCPro.so.1 )
+( cd usr/X11R6/lib ; ln -sf libviaXvMCPro.so.1.0 libviaXvMCPro.so.1 )
+( cd usr/X11R6/lib ; rm -rf libviaXvMCPro.so )
+( cd usr/X11R6/lib ; ln -sf libviaXvMCPro.so.1.0 libviaXvMCPro.so )
+( cd usr/X11R6/lib ; rm -rf libXvMCW.so.1 )
+( cd usr/X11R6/lib ; ln -sf libXvMCW.so.1.0 libXvMCW.so.1 )
+( cd usr/X11R6/lib ; rm -rf libXvMCW.so )
+( cd usr/X11R6/lib ; ln -sf libXvMCW.so.1.0 libXvMCW.so )
 ( cd usr/X11R6/lib ; rm -rf libXrandr.so.2 )
 ( cd usr/X11R6/lib ; ln -sf libXrandr.so.2.0 libXrandr.so.2 )
 ( cd usr/X11R6/lib ; rm -rf libXrandr.so )
@@ -252,10 +252,6 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libXRes.so.1.0 libXRes.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXRes.so )
 ( cd usr/X11R6/lib ; ln -sf libXRes.so.1.0 libXRes.so )
-( cd usr/X11R6/lib ; rm -rf libXcursor.so.1 )
-( cd usr/X11R6/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so.1 )
-( cd usr/X11R6/lib ; rm -rf libXcursor.so )
-( cd usr/X11R6/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so )
 ( cd usr/X11R6/lib ; rm -rf libXevie.so.1 )
 ( cd usr/X11R6/lib ; ln -sf libXevie.so.1.0 libXevie.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXevie.so )
@@ -268,6 +264,10 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/lib ; ln -sf libXdamage.so.1.0 libXdamage.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXdamage.so )
 ( cd usr/X11R6/lib ; ln -sf libXdamage.so.1.0 libXdamage.so )
+( cd usr/X11R6/lib ; rm -rf libXcursor.so.1 )
+( cd usr/X11R6/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so.1 )
+( cd usr/X11R6/lib ; rm -rf libXcursor.so )
+( cd usr/X11R6/lib ; ln -sf libXcursor.so.1.0.2 libXcursor.so )
 ( cd usr/X11R6/lib ; rm -rf libXcomposite.so.1 )
 ( cd usr/X11R6/lib ; ln -sf libXcomposite.so.1.0 libXcomposite.so.1 )
 ( cd usr/X11R6/lib ; rm -rf libXcomposite.so )
@@ -302,36 +302,6 @@ config etc/X11/xdm/Xsession.new
 ( cd usr/X11R6/bin ; ln -sf ioport outw )
 ( cd usr/X11R6/bin ; rm -rf outl )
 ( cd usr/X11R6/bin ; ln -sf ioport outl )
-( cd etc/fonts/conf.d ; rm -rf 20-fix-globaladvance.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-fix-globaladvance.conf 20-fix-globaladvance.conf )
-( cd etc/fonts/conf.d ; rm -rf 20-lohit-gujarati.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-lohit-gujarati.conf 20-lohit-gujarati.conf )
-( cd etc/fonts/conf.d ; rm -rf 20-unhint-small-vera.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/20-unhint-small-vera.conf 20-unhint-small-vera.conf )
-( cd etc/fonts/conf.d ; rm -rf 30-amt-aliases.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-amt-aliases.conf 30-amt-aliases.conf )
-( cd etc/fonts/conf.d ; rm -rf 30-urw-aliases.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/30-urw-aliases.conf 30-urw-aliases.conf )
-( cd etc/fonts/conf.d ; rm -rf 40-generic.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/40-generic.conf 40-generic.conf )
-( cd etc/fonts/conf.d ; rm -rf 49-sansserif.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/49-sansserif.conf 49-sansserif.conf )
-( cd etc/fonts/conf.d ; rm -rf 50-user.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/50-user.conf 50-user.conf )
-( cd etc/fonts/conf.d ; rm -rf 51-local.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/51-local.conf 51-local.conf )
-( cd etc/fonts/conf.d ; rm -rf 60-latin.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/60-latin.conf 60-latin.conf )
-( cd etc/fonts/conf.d ; rm -rf 65-fonts-persian.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-fonts-persian.conf 65-fonts-persian.conf )
-( cd etc/fonts/conf.d ; rm -rf 65-nonlatin.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/65-nonlatin.conf 65-nonlatin.conf )
-( cd etc/fonts/conf.d ; rm -rf 69-unifont.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/69-unifont.conf 69-unifont.conf )
-( cd etc/fonts/conf.d ; rm -rf 80-delicious.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/80-delicious.conf 80-delicious.conf )
-( cd etc/fonts/conf.d ; rm -rf 90-synthetic.conf )
-( cd etc/fonts/conf.d ; ln -sf ../conf.avail/90-synthetic.conf 90-synthetic.conf )
 ( cd etc/X11/rstart/commands ; rm -rf x11 )
 ( cd etc/X11/rstart/commands ; ln -sf x11r6 x11 )
 ( cd etc/X11/rstart/commands ; rm -rf x )
